@@ -4,20 +4,30 @@
 # LICENSE file in the root directory of this source tree.
 
 import distutils.spawn
+
+
+try:
+    import importlib.resources as pkg_resources
+except ImportError:  # For <=3.6
+    import importlib_resources as pkg_resources
+
+import json
 import os
 import re
 from dataclasses import asdict
 from functools import lru_cache
 from pathlib import Path
-from typing import Any, Dict, Optional, Pattern, Set
+from typing import Any, Dict, Pattern, Set
 
 import yaml
+from jsonschema import validate
 
 from fixit.common.base import LintConfig
 from fixit.common.utils import LintRuleCollectionT, import_distinct_rules_from_package
 
 
 LINT_CONFIG_FILE_NAME: Path = Path(".fixit.config.yaml")
+LINT_CONFIG_SCHEMA_NAME: str = "config.schema.json"
 
 # https://gitlab.com/pycqa/flake8/blob/9631dac52aa6ed8a3de9d0983c/src/flake8/defaults.py
 NOQA_INLINE_REGEXP: Pattern[str] = re.compile(
@@ -60,77 +70,50 @@ NOQA_FILE_RULE: Pattern[str] = re.compile(
     + r"(?P<reason>.+)"
 )
 
-
-LIST_SETTINGS = ["formatter", "block_list_patterns", "block_list_rules", "packages"]
-PATH_SETTINGS = ["repo_root", "fixture_dir"]
-NESTED_SETTINGS = ["rule_config"]
 DEFAULT_FORMATTER = ["black", "-"]
+PATH_SETTINGS = ["repo_root", "fixture_dir"]
 
 
 def get_validated_settings(
     file_content: Dict[str, Any], current_dir: Path
 ) -> Dict[str, Any]:
-    settings = {}
-    for list_setting_name in LIST_SETTINGS:
-        if list_setting_name in file_content:
-            if not (
-                isinstance(file_content[list_setting_name], list)
-                and all(isinstance(s, str) for s in file_content[list_setting_name])
-            ):
-                raise TypeError(
-                    f"Expected list of strings for `{list_setting_name}` setting."
-                )
-            settings[list_setting_name] = file_content[list_setting_name]
+    # __package__ should never be none (config.py should not be run directly)
+    # But use .get() to make pyre happy
+    pkg = globals().get("__package__")
+    assert pkg, "No package was found, config types not validated."
+    config = pkg_resources.read_text(pkg, LINT_CONFIG_SCHEMA_NAME)
+    # Validates the types and presence of the keys
+    schema = json.loads(config)
+    validate(instance=file_content, schema=schema)
+
     for path_setting_name in PATH_SETTINGS:
         if path_setting_name in file_content:
             setting_value = file_content[path_setting_name]
-            if not isinstance(setting_value, str):
-                raise TypeError(f"Expected string for `{path_setting_name}` setting.")
             abspath: Path = (current_dir / setting_value).resolve()
         else:
             abspath: Path = current_dir
         # Set path setting to absolute path.
-        settings[path_setting_name] = str(abspath)
+        file_content[path_setting_name] = str(abspath)
 
-    for nested_setting_name in NESTED_SETTINGS:
-        if nested_setting_name in file_content:
-            nested_setting = file_content[nested_setting_name]
-            if not isinstance(nested_setting, dict):
-                raise TypeError(
-                    f"Expected key-value pairs for `{nested_setting_name}` setting."
-                )
-            settings[nested_setting_name] = {}
-            # Verify that each setting is also a mapping
-            for k, v in nested_setting.items():
-                if not isinstance(v, dict):
-                    raise TypeError(
-                        f"Expected key-value pairs for `{v}` setting in {nested_setting_name}."
-                    )
-                settings[nested_setting_name].update({k: v})
-
-    return settings
+    return file_content
 
 
 @lru_cache()
 def get_lint_config() -> LintConfig:
     config = {}
-    current_dir = Path.cwd()
-    previous_dir: Optional[Path] = None
-    while current_dir != previous_dir:
+
+    cwd = Path.cwd()
+    for directory in (cwd, *cwd.parents):
         # Check for config file.
-        possible_config = current_dir / LINT_CONFIG_FILE_NAME
+        possible_config = directory / LINT_CONFIG_FILE_NAME
         if possible_config.is_file():
             with open(possible_config, "r") as f:
                 file_content = yaml.safe_load(f.read())
 
             if isinstance(file_content, dict):
-                config = get_validated_settings(file_content, current_dir)
+                config = get_validated_settings(file_content, directory)
                 break
 
-        # Try to go up a directory.
-        previous_dir = current_dir
-        current_dir = current_dir.parent
-
     # Find formatter executable if there is one.
     formatter_args = config.get("formatter", DEFAULT_FORMATTER)
     exe = distutils.spawn.find_executable(formatter_args[0]) or formatter_args[0]
@@ -156,7 +139,10 @@ def get_rules_from_config() -> LintRuleCollectionT:
     all_names: Set[str] = set()
     for package in lint_config.packages:
         rules_from_pkg = import_distinct_rules_from_package(
-            package, lint_config.block_list_rules, all_names
+            package,
+            lint_config.block_list_rules,
+            all_names,
+            lint_config.allow_list_rules,
         )
         rules.update(rules_from_pkg)
     return rules
