@@ -78,6 +78,7 @@ class InvalidTestCase:
     expected_replacement: Optional[str] = None
     filename: str = DEFAULT_FILENAME
     config: LintConfig = DEFAULT_CONFIG
+    expected_message: Optional[str] = None
 
     @property
     def expected_str(self) -> str:
@@ -85,7 +86,7 @@ class InvalidTestCase:
 
 
 def import_submodules(package: str, recursive: bool = True) -> Dict[str, ModuleType]:
-    """ Import all submodules of a module, recursively, including subpackages. """
+    """Import all submodules of a module, recursively, including subpackages."""
     package: ModuleType = importlib.import_module(package)
     results = {}
     # pyre-fixme[16]: `ModuleType` has no attribute `__path__`.
@@ -104,6 +105,7 @@ def import_distinct_rules_from_package(
     package: str,
     block_list_rules: List[str] = [],
     seen_names: Optional[Set[str]] = None,
+    allow_list_rules: Optional[List[str]] = None,
 ) -> LintRuleCollectionT:
     # Import all rules from the specified package, omitting rules that appear in the block list.
     # Raises error on repeated rule names.
@@ -128,8 +130,10 @@ def import_distinct_rules_from_package(
                         )
                     # Add all names (even block-listed ones) to the `names` set for duplicate checking.
                     seen_names.add(name)
-                    if name not in block_list_rules:
-                        rules.add(obj)
+                    # For backwards compatibility if `allow_list_rules` is missing fall back to all allowed
+                    if not allow_list_rules or name in allow_list_rules:
+                        if name not in block_list_rules:
+                            rules.add(obj)
             except TypeError:
                 continue
     return rules
